@@ -11,7 +11,7 @@ c
 #include "Zptcl.h"
 #include "Zmass.h"
       real*8 emass, emass2 
-
+      include "ZdEdxSpec.h"
 c       MeV unit electron mass.
       parameter(emass = masele*1000., emass2=emass**2)
 
@@ -34,6 +34,40 @@ c     *           loglindbeta =-4.605170186E+00)
      *           loglindbeta =-5.298317367E+00)
       parameter (a = (1.+gra)/2.d0/(logbbbeta-loglindbeta),
      *           b = 2*a*loglindbeta + 1.) 
+
+c////////////
+c      real*8  em
+c      integer iii
+c      data iii /0/
+c      save iii
+c      if(iii .eq. 0) then
+c         write(*,*) ' sh.sa=',sh.sa, ' c=',sh.c,  ' x1=',sh.x1,
+c     *   ' sh.x0=', sh.x0
+c
+c      sh.sa =0.3755
+c      sh.c = -4.435
+c      sh.x1 = 2.5
+c      sh.x0 = 0.0966
+c      em = 2.72
+c         write(*,*) ' sh.sa=',sh.sa, ' c=',sh.c,  ' x1=',sh.x1,
+c     *   ' sh.x0=', sh.x0
+c      iii = 1
+c      endif   
+c////////////
+
+
+c///////////
+c      real*8 betac, gbetac, norm, gbetac2
+c      logical first/.true./
+c      save first, gbetac2, norm
+c      if(first) then
+c         gbetac = 0.35
+c         gbetac2 = gbetac**2
+c         betac = sqrt( gbetac2/(1.0d0+gbetac2) )
+c         norm =1.d0/ betac**0.33333
+c         first = .false.
+c      endif
+c////////////////
 c
 c               energy in MeV unit
       E = aPtcl.fm.p(4)*1000.
@@ -58,15 +92,21 @@ c          x=log10(p/mc)  = log10(g*beta)
 c                  4.605x - dlt
             dltx=4.605*x
          elseif(x .lt. sh.x1) then
+c//////////
             dltx=cb - (sh.x1-x)**3 * sh.sa
+c            dltx=cb - (sh.x1-x)**em * sh.sa
+c///////////
          else
             dltx=cb
          endif
+
+c             max kinetic energy of knock-on
          wm = 2* emass * gb2
      *        /(1.0 + 2.0*g*(emass/mass) +(emass/mass)**2)
+         Tupper = wm/1000.      !  in GeV; used in Urban
 c          first compute full average dE/dx
 c 
-         dedt=sh.a/Beta2 *( sh.b + 0.693 +  log(wm)
+         dedt=sh.a/Beta2 *( sh.b + 0.69315 +  log(wm)
      *        -2.0*Beta2 + dltx)
 c             see if restriceted energy is requested
          if(wm .gt. sh.w0) then
@@ -82,7 +122,12 @@ c               mu, p, etc. spin = 1/2
             integ = integ*sh.a/Beta2
             dedt = dedt - integ
          endif
-
+c///////////////
+c         if( gb2 .lt. gbetac2 ) then
+c                  assume at gb < gbetac, 1/beta**(5/3) dependence
+c            dedt = dedt*norm*(Beta2**0.1667)
+c         endif
+c////////////
       if(truebeta2 .lt. bbbeta2) then
          c = log(dedt) + ( a* logbbbeta - b )*logbbbeta
          if( truebeta2 .gt.  lindbeta2) then
@@ -130,6 +175,3 @@ c
       end
 
 
-
-       
-
