@@ -10,13 +10,16 @@
                             ! 2--> more details.
        integer epHooks(3)   ! number of c, i, r variables user wants to 
                             ! define and inut from epicsfile(epHookc/i/r)
+       integer Ioprim       ! primary container.  code subcode ...etc
+       integer Inpxyz, Inpdir, Inperg, Inpsubcode, Inptime
        parameter(MaxMediaDir = MAX_MEDIA_DIR)
-       parameter( iowk = 11 )
+       parameter( iowk = 11, Ioprim=15 )
        character*128 MediaDir(MaxMediaDir)
        character*100 epHookc(EPMAX_UHOOKC)
        integer epHooki(EPMAX_UHOOKI)
        real*8 epHookr(EPMAX_UHOOKR)
        common /epManag/ epHookr, epHooki, epHooks,
-     *     Nevrun, MsgLevel, IoTrace
+     *  Nevrun, MsgLevel, IoTrace, Inpxyz, Inpdir, Inperg,
+     *  Inpsubcode, Inptime
        common /epManagC/ MediaDir, TraceDir, epHookc
        
