@@ -22,8 +22,6 @@ c                get 1 particle from stack area
 c                icon=0: 1 ptcl gotten in cTrack
 c                       -1: no more ptcl  in the stack
          if(icon .eq. 0) then
-c              do business when a new component appear
-            call epnewComp
             call epfl1
          endif
       enddo
@@ -127,10 +125,15 @@ c             init for 1 event
        Move.Abort = 0     !  if this become non zero for an event, 
                      !  the particle is discarded or event is discarded
 c                 user dependent init
+
        call ui1ev
+
 c               next call sets to icon=1,    if usetip is not
 c               user made.
        call usetip(icon)
+
+
+
 c                 icon=0-->user routine already set prtcl
 c                 icon=1-->no user routine for incident
        if(Trace) then
@@ -150,6 +153,7 @@ c                 icon=1-->no user routine for incident
               call cerrorMsg(msg, 0)
           endif
        endif
+
        end
 c      *******************
        subroutine  epe1ev
@@ -256,6 +260,7 @@ c
            stop 9999
         endif
         Stack(Stack_pos) = aTrack
+
         end
 c       ************************
 c                 put 1ptcl in the stack area (for unknown cn)
@@ -277,7 +282,9 @@ c         convert pos/w into  l.c
            call epw2l(aTrack.cn, aTrack.pos, aTrack.pos)
            call epw2ld(aTrack.cn, aTrack.w,  aTrack.w)
            call eppush(aTrack)
-
+        else
+           call
+     *     cerrorMsg(' epputTrack: ptcl is not in detector', 0)
         endif
       end
 c       ************************
@@ -316,8 +323,8 @@ c     ********************
 c         when a particle moves  to a new component
 c         the following must be done
       Cn = cTrack.cn
-
       MediaNo = Det.Cn2media(Cn)
+
 c       r.l                         cm   / X0           
       MaxPath =abs( Det.cmp(Cn).MaxPathL/Media(MediaNo).X0)
 c         Det.cmp(Cn).MaxPathL may be < 0; which means
@@ -344,7 +351,7 @@ c     ******************************
 c             get 1 particle from the stack area
 c              icon=0:  1 ptcl gotten
 c                  -1:  no more ptcl
-#include  "ZepTrack.h"
+#include  "ZepTrackv.h"
 #include  "ZepStack.h"
 
        
@@ -362,6 +369,12 @@ c                                  if IncGp=0.
           call ep2cosPtcl(aTrack.p)
 
           Stack_pos = Stack_pos - 1
+          Cn = aTrack.cn   ! this may be used in epchckE
+c              do business when a new component appear
+          call epnewComp
+          call epchckE(aTrack, icon)
+          if(icon .ne. 0) goto 10
+
        else
           if(StackDisk .gt. 0) then
              read(StackDisk, end=100) aTrack
@@ -373,6 +386,7 @@ c                                  if IncGp=0.
           icon=-1
        endif
  876    continue
+
         end
 c       *************************
         subroutine epgetTrack(n, aTrack, icon)
@@ -403,7 +417,6 @@ c              until current partile dies or all are put into stack.
 #include  "ZepTrackv.h"
 #include  "Zcnfig.h"
 
-
       integer icon, info
 
       do while (.true.)
@@ -1586,7 +1599,6 @@ c
        real*8 e1, eg, tmp, cosg, cose
        real*8 sine, cs, sn, sing
 
-
 c             sample energies of compton elec. and gamma
        call epcompea(cTrack.p.fm.p(4), eg, e1, cosg, cose)
 
@@ -1606,9 +1618,10 @@ c             sample energies of compton elec. and gamma
 c            w  get new direc-cos
        call eptransVect(cTrack.w,  electron.w,  electron.w)
 
-       call cmkptc(kelec, regptcl, -1, electron)
+       call cmkptc(kelec, regptcl, -1, electron.p)
        electron.p.fm.p(4) = e1
        call epe2p(electron)
+
 c
 c                treat gamma as counterpart of electron (negative d.c)
 c
@@ -1621,10 +1634,12 @@ c
        w.x = -cs*sing
        w.y = -sn*sing
        w.z = cosg
+
        call eptransVect(cTrack.w,  w, cTrack.w)
        cTrack.p.fm.p(4) = eg
        call epe2p(cTrack)
 c            since gamma is likely to have large energy, save first
+
        call eppush(cTrack)
        call eppush(electron)
 
@@ -1643,7 +1658,8 @@ c
 
 
        real*8  e1,  e2,  cos1, cos2
-       real*8 cs, sn,  u,  teta1, teta2
+c       real*8 cs, sn,  u,  teta1, teta2
+       real*8 cs, sn,  u,  teta2
        real*8 sin1, sin2
        
        integer ic
@@ -1717,6 +1733,7 @@ c           treat the other one as counter part    (negative d.c)
        elec2.w.y = -sn*sin2
        elec2.w.z = cos2
        call eptransVect(cTrack.w, elec2.w, elec2.w)
+       call epe2p(elec2)
        call eppush(elec2)
        end
 c      ************
@@ -1826,7 +1843,7 @@ c        cpy parent info.
       w.z = cos1
       call eptransVect(cTrack.w, w, w)
 c        save hi gamma
-      call cmkptc(kphoton, 0, 0, gamma)
+      call cmkptc(kphoton, 0, 0, gamma.p)
       gamma.p.fm.p(4) = eg1
 #ifdef SUBSTREC
       gamma.w = w
@@ -2015,7 +2032,7 @@ c                knock on electron
       w.z = cosr
 c           
       call eptransVect(cTrack.w, w, cTrack.w)
-      call cmkptc(kelec, regptcl, -1, cTrack)
+      call cmkptc(kelec, regptcl, -1, cTrack.p)
       cTrack.p.fm.p(4) = er
       call epe2p(cTrack)
       call eppush(cTrack)
